import React, { useEffect, useState, useCallback } from "react";
import HiroGraphOrm from "@hiro-graph/orm";
import HiroGraphMappings from "@hiro-graph/orm-mappings";
import { HiroGraphContext } from "../contexts";
const safeMappings = HiroGraphMappings.filter(m => m.name !== "AutomationVariable");
export const HiroGraph = ({ config, children }) => {
    const [orm, setOrm] = useState();
    const [me, setMe] = useState();
    const getMe = useCallback(() => orm &&
        Promise.all([
            orm
                .getClient()
                .api.meAccount()
                .then(account => orm.insertRaw(account)),
            orm
                .getClient()
                .api.getMeProfile()
                .then(account => orm.insertRaw(account))
        ])
            .then(([account, profile]) => ({ account, profile }))
            .then(newMe => void setMe(newMe))
            .catch(() => {
            if (process.env && process.env.NODE_ENV === "development") {
                if (!window.sessionStorage.getItem("access_token")) {
                    return;
                }
                window.sessionStorage.removeItem("access_token");
                window.location.reload();
            }
        }), [orm]);
    useEffect(() => {
        if (config.token) {
            setOrm(new HiroGraphOrm(config, safeMappings));
        }
    }, [config]);
    useEffect(() => {
        getMe();
        const i = setInterval(() => {
            getMe();
        }, 30000);
        return () => clearInterval(i);
    }, [getMe]);
    const value = {
        token: config.token,
        orm,
        me
    };
    return (React.createElement(HiroGraphContext.Provider, { value: value }, children));
};
