import React from "react";
import ReactDOM from "react-dom";
import { initSdk } from "@hiro-ui/sdk";
import { init } from "../stores";
import { HiroAppRoot } from "../components";
const getConfigFromEnv = () => {
    const graphUrl = process.env.REACT_APP_GRAPH_URL;
    const authUrl = process.env.REACT_APP_AUTH_URL || `${graphUrl}/api/6/auth/ui/`;
    const redirectUrl = process.env.REACT_APP_REDIRECT_URL || `${graphUrl}/api/6/auth/ui-redirect`;
    const clientId = process.env.REACT_APP_CLIENT_ID;
    const config = {
        graphUrl,
        authUrl,
        clientId,
        redirectUrl
    };
    if (Object.values(config).every(Boolean)) {
        return config;
    }
    return undefined;
};
export class HiroApp {
    constructor({ config, reducers, sagas } = {}) {
        this.render = async (children, target) => {
            const { ready, state, token, graphUrl } = await initSdk(this.config);
            const store = init(state, this.reducers, this.sagas);
            let authConfig;
            if (token && graphUrl) {
                authConfig = {
                    endpoint: graphUrl,
                    token
                };
            }
            ReactDOM.render(React.createElement(HiroAppRoot, { store: store, auth: authConfig }, children), target, ready);
        };
        this.config = config;
        this.reducers = reducers;
        this.sagas = sagas;
        if (!config) {
            this.config = getConfigFromEnv();
        }
    }
}
